body {
    background: #101020;
    font-family: courier;
    font-size: 1.2em;
    margin: 5em;
    color: white;
}

#content {
    border: 1px;
}

p {
    margin-bottom: 1.2em;
    width: 20%;
    color: green;
}

a {
    color: black;
}

a:hover {
    background-color: white;
    text-decoration: none;
    color: #100000;
}

a:link, a:visited {
    color: orange;
}
