body {
  color: black;
  background-color: lemonchiffon;
  font-family: menlo, consolas, courier;
  margin: 5em 6em 5em 5em;
}

h1 {
  color: seagreen;
  font-family: helvetica, sans-serif;
  font-size: 2.7em;
  margin-bottom: 1em;
}

div {
  margin-left: 0.7em;
}
